==> qtjambi-designer-5.15.7-sources.jar: io/qt/designer/QExtensionManager.java <==
package io.qt.designer;


/**
 * <p>Extension management facilities for Qt Designer</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qextensionmanager.html">QExtensionManager</a></p>
 */
public class QExtensionManager extends io.qt.core.QObject
    implements io.qt.designer.QAbstractExtensionManager
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private java.util.Collection<Object> __rcExtension;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QExtensionManager.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QExtensionManager(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QExtensionManager() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qextensionmanager.html#QExtensionManager">QExtensionManager::QExtensionManager(QObject*)</a></p>
     */
    public QExtensionManager(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QExtensionManager instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#extension">QAbstractExtensionManager::extension(QObject*,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid){
        return extension_native_QObject_ptr_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), iid);
    }
    
    private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
    
    /**
     * <p>Overloaded function for {@link #registerExtensions(io.qt.designer.QAbstractExtensionFactory, java.lang.String)}
     *  with <code>iid = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory) {
        registerExtensions(factory, "");
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#registerExtensions">QAbstractExtensionManager::registerExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
        registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
        if (factory != null) {
            if(__rcExtension==null)
                __rcExtension = QtJambi_LibraryUtilities.internal.newRCList();
            __rcExtension.add(factory);
        }
    }
    
    private native static void registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
    
    /**
     * <p>Overloaded function for {@link #unregisterExtensions(io.qt.designer.QAbstractExtensionFactory, java.lang.String)}
     *  with <code>iid = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory) {
        unregisterExtensions(factory, "");
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#unregisterExtensions">QAbstractExtensionManager::unregisterExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
        unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
        if (factory != null) {
            while (__rcExtension != null && __rcExtension.remove(factory)) ;
        }
    }
    
    private native static void unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QExtensionManager(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QExtensionManager(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QExtensionManager instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QExtensionManager.java <==
package io.qt.designer;


/**
 * <p>Extension management facilities for Qt Designer</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qextensionmanager.html">QExtensionManager</a></p>
 */
public class QExtensionManager extends io.qt.core.QObject
    implements io.qt.designer.QAbstractExtensionManager
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private java.util.Collection<Object> __rcExtension;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QExtensionManager.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QExtensionManager(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QExtensionManager() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qextensionmanager.html#QExtensionManager">QExtensionManager::QExtensionManager(QObject*)</a></p>
     */
    public QExtensionManager(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QExtensionManager instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#extension">QAbstractExtensionManager::extension(QObject*,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid){
        return extension_native_QObject_ptr_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), iid);
    }
    
    private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
    
    /**
     * <p>Overloaded function for {@link #registerExtensions(io.qt.designer.QAbstractExtensionFactory, java.lang.String)}
     *  with <code>iid = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory) {
        registerExtensions(factory, (String)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#registerExtensions">QAbstractExtensionManager::registerExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
        registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
        if (factory != null) {
            if(__rcExtension==null)
                __rcExtension = QtJambi_LibraryUtilities.internal.newRCList();
            __rcExtension.add(factory);
        }
    }
    
    private native static void registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
    
    /**
     * <p>Overloaded function for {@link #unregisterExtensions(io.qt.designer.QAbstractExtensionFactory, java.lang.String)}
     *  with <code>iid = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory) {
        unregisterExtensions(factory, (String)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#unregisterExtensions">QAbstractExtensionManager::unregisterExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
        unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
        if (factory != null) {
            while (__rcExtension != null && __rcExtension.remove(factory)) ;
        }
    }
    
    private native static void unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QExtensionManager(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QExtensionManager(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QExtensionManager instance, QDeclarativeConstructor constructor);
    
}
